<?php
// $Id: fast_gallery.admin.inc,v 1.12 2009/04/08 14:26:56 rapsli Exp $

/**
 * @file
 * Administrative page callbacks for the Fast Gallery module.
 *
 * @author Raphael Schr - www.schaerwebdesign.ch
 * @author Nicholas C. Yang - www.nyanginator.com
 */

/**
 * Default Fast Gallery settings page.
 */
function fast_gallery_settings_page($op = NULL) {
	$output = drupal_get_form('fast_gallery_general_settings_form');
	return $output;
}

/**
 * Callback function for admin settings
 */
function fast_gallery_general_settings_form() {

	$form['fg_setup'] = array(
    '#type' => 'fieldset',
    '#title' => t('Setup'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
	);

	$form['fg_setup']['fast_gallery_path'] = array(
    '#type' => 'textfield',
    '#title' => t('Path to Gallery'),
    '#default_value' => variable_get('fast_gallery_path', ''),
    '#description' => t("Path to images from which albums should be created. Relative to site's root."),
	);

	$form['fg_setup']['fast_gallery_title'] = array(
    '#type' => 'textfield',
    '#title' => t('Gallery Title'),
    '#default_value' => variable_get('fast_gallery_title', 'Fast Gallery'),
    '#description' => t('Title to display at the top of the gallery.'),
    '#size' => 30,
	);

	$form['fg_setup']['fast_gallery_path_alias'] = array(
    '#type' => 'textfield',
    '#title' => t('Fast Gallery Path Alias'),
    '#default_value' => variable_get('fast_gallery_path_alias', 'fast_gallery'),
    '#description' => t('Custom set path alias for the gallery.'),
    '#size' => 30,
	);

	$form['fg_appearance'] = array(
    '#type' => 'fieldset',
    '#title' => t('Appearance'),
    '#description' => t('Customize how images and captions are displayed.'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
	);

	$form['fg_appearance']['fast_gallery_nr_per_page'] = array(
    '#type' => 'textfield',
    '#title' => t('Number of images per page'),
    '#default_value' => variable_get('fast_gallery_nr_per_page', 8),
    '#description' => t('Number of images to display on each page.'),
    '#size' => 2,
	);

	$form['fg_appearance']['fast_gallery_row_count'] = array(
    '#type' => 'textfield',
    '#title' => t('Number of images per row'),
    '#default_value' => variable_get('fast_gallery_row_count', 4),
    '#description' => t('Number of images to display on each row. Set this to more than the maximum number of thumbnails that will fit across the page.'),
    '#size' => 2,
	);

	$form['fg_appearance']['fast_gallery_teaser_length'] = array(
    '#type' => 'textfield',
    '#title' => t('Teaser length of captions and folder labels'),
    '#default_value' => variable_get('fast_gallery_teaser_length', 8),
    '#description' => t('Maximum number of words in captions and folder labels'),
    '#size' => 2,
	);

	$option = array(
    'none' => t('<none>'),
    'desc' => t('Description'),
    'date' => t('Date Taken'),
    'name' => t('Filename'),
    'comm' => t('Comment'),
    'copyright' => t('Copyright'),
    'artist' => t('Artist'),
    'xptitle' => t('Windows XP Title'),
    'xpcomments' => t('Windows XP Comments'),
    'xpkeywords' => t('Windows XP Keywords'),
	);
	$form['fg_appearance']['fast_gallery_caption_display_1'] = array(
    '#type' => 'select',
    '#title' => t('Image caption display #1'),
    '#options' => $option,
    '#description' => t('First EXIF field to use for image caption.'),
    '#default_value' => variable_get('fast_gallery_caption_display_1', 'desc'),
	);
	$form['fg_appearance']['fast_gallery_caption_display_2'] = array(
    '#type' => 'select',
    '#title' => t('Image caption display #2'),
    '#options' => $option,
    '#description' => t('Second EXIF field to use for image caption.'),
    '#default_value' => variable_get('fast_gallery_caption_display_2', '<none>'),
	);
	$form['fg_appearance']['fast_gallery_caption_display_3'] = array(
    '#type' => 'select',
    '#title' => t('Image caption display #3'),
    '#options' => $option,
    '#description' => t('Third EXIF field to use for image caption.'),
    '#default_value' => variable_get('fast_gallery_caption_display_3', '<none>'),
	);

	$folderoptions = array(
    'none' => t('<none>'),
    'name' => t('Folder Name'),
    'desc' => t('Description'),
    'comm' => t('Comment'),
    'xptitle' => t('Windows XP Title'),
    'xpcomments' => t('Windows XP Comments'),
    'xpkeywords' => t('Windows XP Keywords'),
	);
	$form['fg_appearance']['fast_gallery_folder_title_display'] = array(
    '#type' => 'select',
    '#title' => t('Custom Folder Thumbnail - Title Display'),
    '#options' => $folderoptions,
    '#description' => t('EXIF field to use for title display on custom folder thumnails.'),
    '#default_value' => variable_get('fast_gallery_folder_title_display', 'name'),
	);
	$form['fg_appearance']['fast_gallery_folder_teaser_display'] = array(
    '#type' => 'select',
    '#title' => t('Custom Folder Thumbnail - Teaser Display'),
    '#options' => $folderoptions,
    '#description' => t('EXIF field to use for teaser display on custom folder thumnails.'),
    '#default_value' => variable_get('fast_gallery_folder_teaser_display', 'none'),
	);

	$form['fg_appearance']['fast_gallery_hierarchy'] = array(
    '#type' => 'checkbox',
    '#title' => t('Hierarchy'),
    '#default_value' => variable_get('fast_gallery_hierarchy', 1),
    '#description' => t('Select if you want to display images in a gallery with folders as opposed to a single flat gallery with no folders.'),
	);

	$form['fg_appearance']['fast_gallery_display_folder'] = array(
    '#type' => 'checkbox',
    '#title' => t('Folders as Text Links'),
    '#default_value' => variable_get('fast_gallery_display_folder', 0),
    '#description' => t('Select if you want to display folders as text links.'),
	);

	$form['fg_appearance']['fast_gallery_use_exif'] = array(
    '#type' => 'checkbox',
    '#title' => t('Read Exif Data'),
    '#default_value' => variable_get('fast_gallery_use_exif', 1),
    '#description' => t('If this option is unchecked no exif data will be read. <b>Warning: </b> This does not work as it should. Leave it on by default!'),
	);

	$js_framework_options = array();
	$js_framework_options[0] = t('<none>');
	$js_framework_default = 0;
	if (module_exists('thickbox'))
	$js_framework_options[1] = t('Thickbox');
	if (module_exists('lightbox2')) {
		$js_framework_default = 2;
		$js_framework_options[2] = t('Lightbox2 (no slideshow)');
		$js_framework_options[3] = t('Lightbox2 (with slideshow)');
	}

	$form['fg_appearance']['fast_gallery_js_framework'] = array(
    '#type' => 'select',
    '#title' => t('Choose your Javascript framework'),
    '#options' => $js_framework_options,
    '#default_value' => variable_get('fast_gallery_js_framework', $js_framework_default),
    '#description' => t('Thickbox and Lightbox are the two options for displaying images.'),
	);

	$ic_link = l('Imagecache', 'admin/build/imagecache');
	$form['fast_gallery_operations'] = array(
    '#type' => 'fieldset',
    '#title' => t('Operations'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    '#tree' => FALSE,
    '#description' => t('Remember to first click Save Settings (if you made any changes) before performing the below operations. Clear the database whenever you change the gallery path. Rescan the database whenever you add images, delete images, move images, or restructure the hierarchy.  Flush Internal Cache to delete and force recaching of Internal Cache thumbnails. If you are using Imagecache, you need to flush thumbnails on the Imagecache settings page: ') . $ic_link,
	);

	$form['fast_gallery_operations']['fast_gallery_clear'] = array(
    '#type' => 'button',
    '#value' => t('Clear DB'),
    '#ahah' => array(
      'path' => 'fast_gallery/clear',
      'method' => 'replace',
      'effect' => 'fade',
      'progress' => array(
        'type' => 'bar',
        'message' => t('Clearing DB')
	),
      'wrapper' => 'attach-wrapper',
	)
	);

	$form['fast_gallery_operations']['fast_gallery_rescan'] = array(
    '#type' => 'button',
    '#value' => t('Rescan'),
    '#ahah' => array(
      'path' => 'fast_gallery/rescan',
      'method' => 'replace',
      'effect' => 'fade',
      'progress' => array(
        'type' => 'bar',
        'message' => t('Scan for new pictures...')
	),
      'wrapper' => 'attach-wrapper',
	)
	);

	$form['fast_gallery_operations']['fast_gallery_flush_thumbs'] = array(
    '#type' => 'button',
    '#value' => t('Flush Internal Cache'),
    '#ahah' => array(
      'path' => 'fast_gallery/flush',
      'method' => 'replace',
      'effect' => 'fade',
      'progress' => array(
        'type' => 'bar',
        'message' => t('Flushing thumbnails')
	),
      'wrapper' => 'attach-wrapper',
	)
	);

	$form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save Settings'),
	);

	return $form;
}

/**
 * Validation function for Fast Gallery General Settings form.
 */
function fast_gallery_general_settings_form_validate($form, &$form_state) {
	if (!is_numeric($form_state['values']['fast_gallery_nr_per_page'])) {
		form_error($form['fg_appearance']['fast_gallery_nr_per_page'], t('Number of images per page has to be numeric.'));
	}
	if ($form_state['values']['fast_gallery_nr_per_page'] < 1) {
		form_error($form['fg_appearance']['fast_gallery_nr_per_page'], t('Number of images per page has to be positive.'));
	}

	if (!is_numeric($form_state['values']['fast_gallery_row_count'])) {
		form_error($form['fg_appearance']['fast_gallery_row_count'], t('Number of images per row has to be numeric.'));
	}
	if ($form_state['values']['fast_gallery_row_count'] < 1) {
		form_error($form['fg_appearance']['fast_gallery_row_count'], t('Number of images per row has to be positive.'));
	}

	if (!is_numeric($form_state['values']['fast_gallery_teaser_length'])) {
		form_error($form['fg_appearance']['fast_gallery_teaser_length'], t('Teaser length has to be numeric.'));
	}
	if ($form_state['values']['fast_gallery_teaser_length'] < 1) {
		form_error($form['fg_appearance']['fast_gallery_teaser_length'], t('Teaser length has to be positive.'));
	}

	$path = utf8_decode($form_state['values']['fast_gallery_path']);
	if (!file_exists($path)) {
		form_error($form['fg_setup']['fast_gallery_path'], t('This folder doesn\'t exist.'));
	}
	// Add trailing slash to path
	if (substr($path, -1, 1) != '/') {
		$path .= '/';
		$form_state['values']['fast_gallery_path'] = utf8_encode($path);
	}

	$path = $form_state['values']['fast_gallery_path_alias'];
	if (preg_match('/[ \\\*:?<>|\"&]/', $path) != 0) {
		form_error($form['fg_setup']['fast_gallery_path_alias'], t('Path alias cannot contain any of these characters: [space] \ * : ? < > | " &'));
	}
	// Remove trailing slash from path alias
	if (substr($path, -1, 1) == '/') {
		$path = substr($path, 0, -1);
		$form_state['values']['fast_gallery_path_alias'] = $path;
	}
}

/**
 * Process the submitted general settings form. Copied mostly from
 * system_settings_form_submit(). Need to also do additional processing and
 * changes to database for any changes in title and alias.
 */
function fast_gallery_general_settings_form_submit($form, &$form_state) {
	// Check if the alias was changed and update database entries if so
	$current_route = variable_get('fast_gallery_path_alias', 'fast_gallery');
	$new_route = $form_state['values']['fast_gallery_path_alias'];
	if ($current_route != $new_route) {
		$sql = "UPDATE {menu_router} SET path='%s', tab_root='%s' WHERE page_callback='fast_gallery_page'";
		db_query($sql, $new_route, $new_route);
		$sql = "UPDATE {menu_links} SET link_path='%s', router_path='%s' WHERE
      link_path='%s'";
		db_query($sql, $new_route, $new_route, $current_route);
	}

	// Check if the title was changed and update database entries if so
	$current_title = variable_get('fast_gallery_title', 'Fast Gallery');
	$new_title = $form_state['values']['fast_gallery_title'];
	if ($current_title != $new_title) {
		$sql = "UPDATE {menu_router} SET title='%s' WHERE page_callback='fast_gallery_page'";
		db_query($sql, $new_title);
		$sql = "UPDATE {menu_links} SET link_title='%s' WHERE link_path='%s'";
		db_query($sql, $new_title, $new_route);
	}

	// Now process and save the form settings

	// Exclude unnecessary elements
	unset($form_state['values']['submit'], $form_state['values']['reset'], $form_state['values']['form_id'], $form_state['values']['op'], $form_state['values']['form_token'], $form_state['values']['form_build_id']);

	// Update variables
	foreach ($form_state['values'] as $key => $value) {
		if (is_array($value) && isset($form_state['values']['array_filter'])) {
			$value = array_keys(array_filter($value));
		}
		variable_set($key, $value);
	}

	drupal_set_message(t('The configuration options have been saved.'));

	menu_cache_clear_all();
	cache_clear_all();
	drupal_rebuild_theme_registry();
}

/**
 * Advanced Settings form
 */
function fast_gallery_advanced_settings_form() {
	$optionPresets = array();
	$optionPresetsBig = array();
	
	if (module_exists('imagecache')) {
		$arICPresetts = imagecache_presets();
		$optionPresets = array();
		foreach ($arICPresetts as $value) {
			$optionPresets[$value['presetname']] = $value['presetname'];
		}

		$optionPresetsBig = $optionPresets;


		$thumb_preset = variable_get('fast_gallery_ic', '<none>');
		if (!in_array($thumb_preset, $optionPresets)) {
			drupal_set_message('Previously saved Imagecache thumbnail preset: "'.$thumb_preset.'" not found! (Was it deleted?) Please resave your Imagecache settings.');
			variable_set('fast_gallery_ic', '<none>');
		}
		$big_preset = variable_get('fast_gallery_ic_big', '<none>');
		if (!in_array($big_preset, $optionPresetsBig)) {
			drupal_set_message('Previously saved Imagecache full-size preset: "'.$big_preset.'" not found! (Was it deleted?) Please resave your Imagecache settings.');
			variable_set('fast_gallery_ic_big', '<none>');
		}

		$optionPresets['<none>'] = '<none>';
		$optionPresetsBig['<none>'] = '<none>';
	}

	$ic_link = l('Imagecache', 'admin/build/imagecache');
	$form['ic'] = array(
    '#type' => 'fieldset',
    '#title' => t('ImageCache'),
    '#description' => t(''),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    '#description' => t('When you uninstall Fast Gallery, Imagecache presets are left intact. Please be sure to check the Imagecache preset page to see what presets are installed: ') . $ic_link,
	);

	$form['ic']['fast_gallery_presets_install'] = array(
    '#type' => 'button',
    '#value' => t('Install IC Presets'),
    '#ahah' => array(
      'path' => 'fast_gallery/presets_install',
      'method' => 'replace',
      'effect' => 'fade',
      'progress' => array(
        'type' => 'bar',
        'message' => t('Installing Imagecache presets...')
	),
      'wrapper' => 'attach-wrapper',
	)
	);

	$form['ic']['fast_gallery_ic'] = array(
    '#type' => 'select',
    '#title' => t('Fill in the Imagecache preset name for thumbnails'),
    '#options' => $optionPresets,
    '#default_value' => variable_get('fast_gallery_ic', '<none>'),
    '#description' => t('Choose Imagecache preset that should be applied to image thumbnails. Remember to adjust the CSS .single-image width to correspond with the Imagecache setting\'s width and refresh your browser.'),
	);

	$form['ic']['fast_gallery_ic_big'] = array(
    '#type' => 'select',
    '#title' => t('Fill in the Imagecache preset name for full-size display'),
    '#default_value' => variable_get('fast_gallery_ic_big', '<none>'),
    '#options' => $optionPresetsBig,
    '#description' => t('Choose Imagecache preset that should be applied to full-size images. Use &lt;none&gt; if you just want to use the original image.'),
	);

	$form['intcache'] = array(
    '#type' => 'fieldset',
    '#title' => t('Internal Cache'),
    '#description' => t('Internal Cache settings (if you aren\'t using ImageCache). The thumbnail is created based on the longer dimension.'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
	);
	$form['intcache']['fast_gallery_intcache_width'] = array(
    '#type' => 'textfield',
    '#title' => t('Width'),
    '#default_value' => variable_get('fast_gallery_intcache_width', 150),
    '#description' => t('Width of thumbnails generated by Internal Cache.  Remember to adjust the CSS .single-image width to correspond with the width here and refresh your browser.'),
    '#size' => 2,
	);
	$form['intcache']['fast_gallery_intcache_height'] = array(
    '#type' => 'textfield',
    '#title' => t('Height'),
    '#default_value' => variable_get('fast_gallery_intcache_height', 100),
    '#description' => t('Height of thumbnails generated by Internal Cache.'),
    '#size' => 2,
	);

	$optionSorting = array(
    'asc' => t('Ascending'),
    'desc' => t('Descending')
	);

	$option = array(
    'path' => t('Name'),
    'date' => t('Date taken'),
    'filec'=> t('File created'),
    'rand' => t('Random'),
	);

	$form['fg_image_sorting'] = array(
    '#type' => 'fieldset',
    '#title' => t('Sorting Images'),
    '#description' => t('Various image sorting options.'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
	);

	$form['fg_image_sorting']['fast_gallery_sort'] = array(
    '#type' => 'select',
    '#title' => t('Sort by'),
    '#options' => $option,
    '#default_value' => variable_get('fast_gallery_sort', 'date'),
	);

	$form['fg_image_sorting']['fast_gallery_direction'] = array(
    '#type' => 'select',
    '#title' => t('Ascending/Descending'),
    '#options' => $optionSorting,
    '#default_value' => variable_get('fast_gallery_direction', 'desc'),
	);

	$form['fg_folder_sorting'] = array(
    '#type' => 'fieldset',
    '#title' => t('Sorting Folders'),
    '#description' => t('The first picture of the folder is taken as sorting criteria for options that require a picture.'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
	);

	$form['fg_folder_sorting']['fast_gallery_sort_folder'] = array(
    '#type' => 'select',
    '#title' => t('Sort by'),
    '#options' => $option,
    '#default_value' => variable_get('fast_gallery_sort_folder', 'date'),
	);

	$form['fg_folder_sorting']['fast_gallery_folder_direction'] = array(
    '#type' => 'select',
    '#title' => t('Ascending/Descending'),
    '#options' => $optionSorting,
    '#default_value' => variable_get('fast_gallery_folder_direction', 'desc'),
	);

	$form['fg_flat_sorting'] = array(
    '#type' => 'fieldset',
    '#title' => t('Sorting for Hierarchy Disabled'),
    '#description' => t('When Hierarchy is disabled, this sorting option will be used.'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
	);

	$form['fg_flat_sorting']['fast_gallery_sort_flat'] = array(
    '#type' => 'select',
    '#title' => t('Sort by'),
    '#options' => $option,
    '#default_value' => variable_get('fast_gallery_sort_flat', 'date'),
	);

	$form['fg_flat_sorting']['fast_gallery_flat_direction'] = array(
    '#type' => 'select',
    '#title' => t('Ascending/Descending'),
    '#options' => $optionSorting,
    '#default_value' => variable_get('fast_gallery_flat_direction', 'desc'),
	);

	$options = array(
	0 => t('Manual'),
	1 => t('Automatic')
	);

	$form['fg_update'] = array(
    '#type' => 'fieldset',
    '#title' => t('Updating'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
	);

	$form['fg_update']['fast_gallery_update_mode'] = array(
    '#type' => 'radios',
    '#title' => t('Update mode'),
    '#options' => $options,
    '#default_value' => variable_get('fast_gallery_update_mode', 0),
    '#description' => t('Choose automatic to update the gallery with every cron job. Choose manual to update by clicking on Rescan on the General settings page.'),
	);

	$form['fg_misc'] = array(
    '#type' => 'fieldset',
    '#title' => t('Miscellaneous'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
	);

	$form['fg_misc']['fast_gallery_utf8_captions'] = array(
    '#type' => 'checkbox',
    '#title' => t('Toggle UTF-8 conversion of captions'),
    '#default_value' => variable_get('fast_gallery_utf8_captions', 0),
    '#description' => t('Use this to toggle UTF-8 conversion of captions.  This might be required depending on your server\'s settings.  Some servers will automatically encode and decode from and to UTF-8 when accessing the database (leave this unchecked). Other servers won\'t (leave checked). If you are having trouble reading your gallery directory, also try enabling this.'),
	);

	$form['fg_misc']['fast_gallery_all_images_in_popup'] = array(
    '#type' => 'checkbox',
    '#title' => t('View All Images in Popup Window (requires Javascript framework enabled)'),
    '#default_value' => variable_get('fast_gallery_all_images_in_popup', 1), '#description' => t('Enable this if you want to be able to click "next" and "previous" image in the Javascript popup window to access all images in the current folder, instead of just on the current page.'),
	);

	$form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save Settings'),
	);

	return $form;
}

/**
 * Validation function for Fast Gallery Advanced Settings form.
 */
function fast_gallery_advanced_settings_form_validate($form, &$form_state) {
	if (!is_numeric($form_state['values']['fast_gallery_intcache_width'])) {
		form_error($form['intcache']['fast_gallery_intcache_width'], t('Internal Cache width has to be numeric.'));
	}
	if ($form_state['values']['fast_gallery_intcache_width'] < 1) {
		form_error($form['intcache']['fast_gallery_intcache_width'], t('Internal Cache width has to be positive.'));
	}

	if (!is_numeric($form_state['values']['fast_gallery_intcache_height'])) {
		form_error($form['intcache']['fast_gallery_intcache_height'], t('Internal Cache height has to be numeric.'));
	}
	if ($form_state['values']['fast_gallery_intcache_height'] < 1) {
		form_error($form['intcache']['fast_gallery_intcache_height'], t('Internal Cache height has to be positive.'));
	}
}

function fast_gallery_advanced_settings_form_submit($form, &$form_state) {
	// Exclude unnecessary elements
	unset($form_state['values']['submit'], $form_state['values']['reset'], $form_state['values']['form_id'], $form_state['values']['op'], $form_state['values']['form_token'], $form_state['values']['form_build_id']);

	// Update variables
	foreach ($form_state['values'] as $key => $value) {
		if (is_array($value) && isset($form_state['values']['array_filter'])) {
			$value = array_keys(array_filter($value));
		}
		variable_set($key, $value);
	}

	drupal_set_message(t('The configuration options have been saved.'));

	menu_cache_clear_all();
	cache_clear_all();
	drupal_rebuild_theme_registry();
}

function fast_gallery_fileupload_form(){
	$form['fast_gallery_upload_dir'] = array(
		'#type'	=>	'textfield',
		'#title'=>	t('Target directory'),
		'#default_value'	=>	variable_get('fast_gallery_upload_dir', 'sites/default/files/gallery/'),
		'#description'	=>	t('Make sure to end the path with "/"! Else it will not work!'),
	);


	return system_settings_form($form);
}

/**
 * Callback function to display the upload page
 * @return String html
 */
function fast_gallery_fileupload(){
	$out = '';
	$codebase = base_path(). drupal_get_path('module','fast_gallery');

	$out .= drupal_get_form('fast_gallery_fileupload_form');
	drupal_set_message(t('Make sure the the folders have write permission!'));
	$out .= t('Be aware, that filenames will be overwritten! This function should not be used yet!');
	$out .= '<applet width="715" height="500"
					codebase = "' . $codebase . '" 
					archive="jumploader_z.jar" 
					code="jmaster.jumploader.app.JumpLoaderApplet.class" name="jumpLoaderApplet">
			    	<param value="true" name="uc_imageEditorEnabled"/>
					<param value="'.base_path().'fast_gallery/multiple_upload" name="uc_uploadUrl"/>
			</applet>';
	return $out;
}

/**
 * Processing the uploaded images.
 */
function fast_gallery_upload_process(){
	//
	//    specify upload directory - storage
	//    for reconstructed uploaded files
	$upload_dir = variable_get('fast_gallery_upload_dir', 'sites/default/files/gallery/');

	if(move_uploaded_file($_FILES['file']['tmp_name'], $upload_dir.$_FILES['file']['name'])) {
		drupal_set_message("Uploaded files");
	} else{
		drupal_set_message("There was an error uploading the file, please try again!");
	}
}